/* ============================================================================
 * File Name: myEEPROM
 *   version v0.1
 *   Development version of the myEEPROM component
 *
 * Description:
 *   Saves upto 2047 bytes of data into EEPROM (+CRC8 1 byte)
 *   CRC8 check upon EEPROM read,
 *   variable seed value for CRC operation,
 *   variable EEPROM address
 *   multiple instances of component allow to save several buffers
 *   Temperature check for operation in adverse conditions
 *
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/

#ifndef `$INSTANCE_NAME`_H
#define `$INSTANCE_NAME`_H
    
#include <project.h>            

  
#define true  1
#define false 0

/***************************************
*        read-only parameters
***************************************/  
#define `$INSTANCE_NAME`_CRC_SEED_VAL            `$crc_seed`        //pefrorm CRC check when reading EEPROM, default=1 
#define `$INSTANCE_NAME`_check_crc_flag          `$check_crc`       //enable if temperature of operation may deviate for more than 10 degC
#define `$INSTANCE_NAME`_set_Temp_flag           `$check_Temp`      //CRC8 seed value [0-255], can use aka version number?
#define `$INSTANCE_NAME`_EEPROM_CONFIG_LOCATION  `$eeprom_location` //starting row in EEPROM, default 0, valid range [0-127] for 2048 EEPROM (depends on silicon)
    
    
/***************************************
*        global variables
***************************************/  


    
/***************************************
*        Encapsulation 
***************************************/
#define `$INSTANCE_NAME`_Initialized            `$INSTANCE_NAME`_GetInitStatus()  // return True if initialaize successfully    
#define `$INSTANCE_NAME`_SizeOfBuffer           `$INSTANCE_NAME`_GetBufferSize()  // return size of the config buffer in bytes
    
    
/***************************************
*        Function Prototypes 
***************************************/

uint8 `$INSTANCE_NAME`_Start(uint8 *ConfigPointer, uint16 size);  //initialize storage
void  `$INSTANCE_NAME`_Stop ();             //free and nil
uint8 `$INSTANCE_NAME`_Read();              //read EEPROM into Config buffer, return 1 if CRC check passed OK
uint8 `$INSTANCE_NAME`_Write();             //store Config buffer in EEPROM, return=1 if success
uint8 `$INSTANCE_NAME`_GetInitStatus();     //return True if initialaize successfully
uint8 `$INSTANCE_NAME`_GetBufferSize();     //return size of the config buffer in bytes


#endif
/* [] END OF FILE */
